@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class MysqlAccessRule(
-    cdktf.TerraformResource,
+    _cdktf_9a9027ec.TerraformResource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-oraclepaas.mysqlAccessRule.MysqlAccessRule",
 ):
@@ -30,7 +30,7 @@ class MysqlAccessRule(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
         destination: builtins.str,
@@ -39,17 +39,17 @@ class MysqlAccessRule(
         service_instance_id: builtins.str,
         source: builtins.str,
         description: typing.Optional[builtins.str] = None,
-        enabled: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        enabled: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         id: typing.Optional[builtins.str] = None,
         protocol: typing.Optional[builtins.str] = None,
-        timeouts: typing.Optional[typing.Union["MysqlAccessRuleTimeouts", typing.Dict[str, typing.Any]]] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        timeouts: typing.Optional[typing.Union["MysqlAccessRuleTimeouts", typing.Dict[builtins.str, typing.Any]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/oraclepaas/r/mysql_access_rule oraclepaas_mysql_access_rule} Resource.
 
@@ -74,30 +74,7 @@ class MysqlAccessRule(
         :param provisioners: 
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id_: builtins.str,
-                *,
-                destination: builtins.str,
-                name: builtins.str,
-                ports: builtins.str,
-                service_instance_id: builtins.str,
-                source: builtins.str,
-                description: typing.Optional[builtins.str] = None,
-                enabled: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
-                id: typing.Optional[builtins.str] = None,
-                protocol: typing.Optional[builtins.str] = None,
-                timeouts: typing.Optional[typing.Union[MysqlAccessRuleTimeouts, typing.Dict[str, typing.Any]]] = None,
-                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
-                count: typing.Optional[jsii.Number] = None,
-                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-                provider: typing.Optional[cdktf.TerraformProvider] = None,
-                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__2efedfc41e8ac859d68ef0b4943f3c0675044c3870148a827cbfbfb46477c403)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = MysqlAccessRuleConfig(
@@ -190,8 +167,8 @@ class MysqlAccessRule(
     @jsii.member(jsii_name="enabledInput")
     def enabled_input(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "enabledInput"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "enabledInput"))
 
     @builtins.property
     @jsii.member(jsii_name="idInput")
@@ -227,8 +204,8 @@ class MysqlAccessRule(
     @jsii.member(jsii_name="timeoutsInput")
     def timeouts_input(
         self,
-    ) -> typing.Optional[typing.Union["MysqlAccessRuleTimeouts", cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union["MysqlAccessRuleTimeouts", cdktf.IResolvable]], jsii.get(self, "timeoutsInput"))
+    ) -> typing.Optional[typing.Union["MysqlAccessRuleTimeouts", _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union["MysqlAccessRuleTimeouts", _cdktf_9a9027ec.IResolvable]], jsii.get(self, "timeoutsInput"))
 
     @builtins.property
     @jsii.member(jsii_name="description")
@@ -238,9 +215,7 @@ class MysqlAccessRule(
     @description.setter
     def description(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__52e33c1e87f2e16fb73d4777422c051f1e060035201505a52aa3295b2b34b45d)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "description", value)
 
@@ -252,23 +227,22 @@ class MysqlAccessRule(
     @destination.setter
     def destination(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__8c5e4cb9cb3c8f9a8213ee34ea65916c4ef72d488881d116ebd64b804972e48c)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "destination", value)
 
     @builtins.property
     @jsii.member(jsii_name="enabled")
-    def enabled(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
-        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "enabled"))
+    def enabled(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
+        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "enabled"))
 
     @enabled.setter
-    def enabled(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+    def enabled(
+        self,
+        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+    ) -> None:
         if __debug__:
-            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__bc5c1ec48257df78f741db12d30d7c90f1637f18c5c8c880601c40967c67016b)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enabled", value)
 
@@ -280,9 +254,7 @@ class MysqlAccessRule(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__2c7bbe9f82c79d1e9314adc206388cab8bb38450d39044e1ec4b7d8f9fc26f60)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -294,9 +266,7 @@ class MysqlAccessRule(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__a347469a153f83ff4a8a9ac1a2a344eeba7e5654f8f86397bfacdcd0b0e504e9)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -308,9 +278,7 @@ class MysqlAccessRule(
     @ports.setter
     def ports(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__dcc0af75418c31201b708566590b77e956c660292229425d311df4686244f72d)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "ports", value)
 
@@ -322,9 +290,7 @@ class MysqlAccessRule(
     @protocol.setter
     def protocol(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__874b4ae414db991a5db6d7c68a5becd9b3f05057388d022591f00098c4bf84d5)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "protocol", value)
 
@@ -336,9 +302,7 @@ class MysqlAccessRule(
     @service_instance_id.setter
     def service_instance_id(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__4ab1d58a59fbd6de87fb201e9da74d28eba3b9c836e1cab99efca1ca4a7857c7)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "serviceInstanceId", value)
 
@@ -350,16 +314,14 @@ class MysqlAccessRule(
     @source.setter
     def source(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__7248e18abe6dd0f729c95eb4cf4998c7ac58dc94f13c1f2523f071fdd50a7053)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "source", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-oraclepaas.mysqlAccessRule.MysqlAccessRuleConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -380,27 +342,27 @@ class MysqlAccessRule(
         "timeouts": "timeouts",
     },
 )
-class MysqlAccessRuleConfig(cdktf.TerraformMetaArguments):
+class MysqlAccessRuleConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         destination: builtins.str,
         name: builtins.str,
         ports: builtins.str,
         service_instance_id: builtins.str,
         source: builtins.str,
         description: typing.Optional[builtins.str] = None,
-        enabled: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        enabled: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         id: typing.Optional[builtins.str] = None,
         protocol: typing.Optional[builtins.str] = None,
-        timeouts: typing.Optional[typing.Union["MysqlAccessRuleTimeouts", typing.Dict[str, typing.Any]]] = None,
+        timeouts: typing.Optional[typing.Union["MysqlAccessRuleTimeouts", typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param connection: 
@@ -422,32 +384,11 @@ class MysqlAccessRuleConfig(cdktf.TerraformMetaArguments):
         :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/oraclepaas/r/mysql_access_rule#timeouts MysqlAccessRule#timeouts}
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if isinstance(timeouts, dict):
             timeouts = MysqlAccessRuleTimeouts(**timeouts)
         if __debug__:
-            def stub(
-                *,
-                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
-                count: typing.Optional[jsii.Number] = None,
-                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-                provider: typing.Optional[cdktf.TerraformProvider] = None,
-                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
-                destination: builtins.str,
-                name: builtins.str,
-                ports: builtins.str,
-                service_instance_id: builtins.str,
-                source: builtins.str,
-                description: typing.Optional[builtins.str] = None,
-                enabled: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
-                id: typing.Optional[builtins.str] = None,
-                protocol: typing.Optional[builtins.str] = None,
-                timeouts: typing.Optional[typing.Union[MysqlAccessRuleTimeouts, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__4efc2a64ef36c864267cffdf7df4ee5a2a32c9bbef1e5753878bbb4944ee6eba)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -465,7 +406,7 @@ class MysqlAccessRuleConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument protocol", value=protocol, expected_type=type_hints["protocol"])
             check_type(argname="argument timeouts", value=timeouts, expected_type=type_hints["timeouts"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "destination": destination,
             "name": name,
             "ports": ports,
@@ -500,12 +441,12 @@ class MysqlAccessRuleConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -516,46 +457,48 @@ class MysqlAccessRuleConfig(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def destination(self) -> builtins.str:
@@ -601,10 +544,10 @@ class MysqlAccessRuleConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def enabled(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
         '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/oraclepaas/r/mysql_access_rule#enabled MysqlAccessRule#enabled}.'''
         result = self._values.get("enabled")
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)
 
     @builtins.property
     def id(self) -> typing.Optional[builtins.str]:
@@ -660,16 +603,10 @@ class MysqlAccessRuleTimeouts:
         :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/oraclepaas/r/mysql_access_rule#delete MysqlAccessRule#delete}.
         '''
         if __debug__:
-            def stub(
-                *,
-                create: typing.Optional[builtins.str] = None,
-                delete: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__6a6f9c4b82e49c756124afb462d6fc4e8229836b152e69ef2395798c8ba347a9)
             check_type(argname="argument create", value=create, expected_type=type_hints["create"])
             check_type(argname="argument delete", value=delete, expected_type=type_hints["delete"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if create is not None:
             self._values["create"] = create
         if delete is not None:
@@ -700,13 +637,13 @@ class MysqlAccessRuleTimeouts:
 
 
 class MysqlAccessRuleTimeoutsOutputReference(
-    cdktf.ComplexObject,
+    _cdktf_9a9027ec.ComplexObject,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-oraclepaas.mysqlAccessRule.MysqlAccessRuleTimeoutsOutputReference",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
     ) -> None:
         '''
@@ -714,12 +651,7 @@ class MysqlAccessRuleTimeoutsOutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            def stub(
-                terraform_resource: cdktf.IInterpolatingParent,
-                terraform_attribute: builtins.str,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__9a68b5983d11f5914c79cd70e09257ecc67e90afa0edb0d3728f162d88dd3255)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -750,9 +682,7 @@ class MysqlAccessRuleTimeoutsOutputReference(
     @create.setter
     def create(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__8e77023fdc312a646392b3dc31146e0db2b4d8fa08472343f019635ffe9cc7be)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "create", value)
 
@@ -764,9 +694,7 @@ class MysqlAccessRuleTimeoutsOutputReference(
     @delete.setter
     def delete(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__1cba1092ef2b7057cbc225ae2f9dbaa120c894c73deffb5552c285577b86540d)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "delete", value)
 
@@ -774,20 +702,16 @@ class MysqlAccessRuleTimeoutsOutputReference(
     @jsii.member(jsii_name="internalValue")
     def internal_value(
         self,
-    ) -> typing.Optional[typing.Union[MysqlAccessRuleTimeouts, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[MysqlAccessRuleTimeouts, cdktf.IResolvable]], jsii.get(self, "internalValue"))
+    ) -> typing.Optional[typing.Union[MysqlAccessRuleTimeouts, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[MysqlAccessRuleTimeouts, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "internalValue"))
 
     @internal_value.setter
     def internal_value(
         self,
-        value: typing.Optional[typing.Union[MysqlAccessRuleTimeouts, cdktf.IResolvable]],
+        value: typing.Optional[typing.Union[MysqlAccessRuleTimeouts, _cdktf_9a9027ec.IResolvable]],
     ) -> None:
         if __debug__:
-            def stub(
-                value: typing.Optional[typing.Union[MysqlAccessRuleTimeouts, cdktf.IResolvable]],
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__bf788106623d616f8421e1b7ae3ea46aa69dcbef7ffcfe296907f8db019db021)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -800,3 +724,138 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__2efedfc41e8ac859d68ef0b4943f3c0675044c3870148a827cbfbfb46477c403(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    destination: builtins.str,
+    name: builtins.str,
+    ports: builtins.str,
+    service_instance_id: builtins.str,
+    source: builtins.str,
+    description: typing.Optional[builtins.str] = None,
+    enabled: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    id: typing.Optional[builtins.str] = None,
+    protocol: typing.Optional[builtins.str] = None,
+    timeouts: typing.Optional[typing.Union[MysqlAccessRuleTimeouts, typing.Dict[builtins.str, typing.Any]]] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__52e33c1e87f2e16fb73d4777422c051f1e060035201505a52aa3295b2b34b45d(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8c5e4cb9cb3c8f9a8213ee34ea65916c4ef72d488881d116ebd64b804972e48c(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__bc5c1ec48257df78f741db12d30d7c90f1637f18c5c8c880601c40967c67016b(
+    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__2c7bbe9f82c79d1e9314adc206388cab8bb38450d39044e1ec4b7d8f9fc26f60(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a347469a153f83ff4a8a9ac1a2a344eeba7e5654f8f86397bfacdcd0b0e504e9(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__dcc0af75418c31201b708566590b77e956c660292229425d311df4686244f72d(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__874b4ae414db991a5db6d7c68a5becd9b3f05057388d022591f00098c4bf84d5(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4ab1d58a59fbd6de87fb201e9da74d28eba3b9c836e1cab99efca1ca4a7857c7(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7248e18abe6dd0f729c95eb4cf4998c7ac58dc94f13c1f2523f071fdd50a7053(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4efc2a64ef36c864267cffdf7df4ee5a2a32c9bbef1e5753878bbb4944ee6eba(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    destination: builtins.str,
+    name: builtins.str,
+    ports: builtins.str,
+    service_instance_id: builtins.str,
+    source: builtins.str,
+    description: typing.Optional[builtins.str] = None,
+    enabled: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    id: typing.Optional[builtins.str] = None,
+    protocol: typing.Optional[builtins.str] = None,
+    timeouts: typing.Optional[typing.Union[MysqlAccessRuleTimeouts, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__6a6f9c4b82e49c756124afb462d6fc4e8229836b152e69ef2395798c8ba347a9(
+    *,
+    create: typing.Optional[builtins.str] = None,
+    delete: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9a68b5983d11f5914c79cd70e09257ecc67e90afa0edb0d3728f162d88dd3255(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8e77023fdc312a646392b3dc31146e0db2b4d8fa08472343f019635ffe9cc7be(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1cba1092ef2b7057cbc225ae2f9dbaa120c894c73deffb5552c285577b86540d(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__bf788106623d616f8421e1b7ae3ea46aa69dcbef7ffcfe296907f8db019db021(
+    value: typing.Optional[typing.Union[MysqlAccessRuleTimeouts, _cdktf_9a9027ec.IResolvable]],
+) -> None:
+    """Type checking stubs"""
+    pass
