@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class OraclepaasProvider(
-    cdktf.TerraformProvider,
+    _cdktf_9a9027ec.TerraformProvider,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-oraclepaas.provider.OraclepaasProvider",
 ):
@@ -30,7 +30,7 @@ class OraclepaasProvider(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         identity_domain: builtins.str,
@@ -39,7 +39,7 @@ class OraclepaasProvider(
         alias: typing.Optional[builtins.str] = None,
         application_endpoint: typing.Optional[builtins.str] = None,
         database_endpoint: typing.Optional[builtins.str] = None,
-        insecure: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        insecure: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         java_endpoint: typing.Optional[builtins.str] = None,
         max_retries: typing.Optional[jsii.Number] = None,
         mysql_endpoint: typing.Optional[builtins.str] = None,
@@ -60,23 +60,7 @@ class OraclepaasProvider(
         :param mysql_endpoint: The HTTP endpoint for Oracle MySQL operations. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/oraclepaas#mysql_endpoint OraclepaasProvider#mysql_endpoint}
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                identity_domain: builtins.str,
-                password: builtins.str,
-                user: builtins.str,
-                alias: typing.Optional[builtins.str] = None,
-                application_endpoint: typing.Optional[builtins.str] = None,
-                database_endpoint: typing.Optional[builtins.str] = None,
-                insecure: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
-                java_endpoint: typing.Optional[builtins.str] = None,
-                max_retries: typing.Optional[jsii.Number] = None,
-                mysql_endpoint: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__cd1e7e516dd8bd0cd036abeaf45b9cabb3becd25c14cfba0ba8459e9673acdc7)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         config = OraclepaasProviderConfig(
@@ -155,8 +139,8 @@ class OraclepaasProvider(
     @jsii.member(jsii_name="insecureInput")
     def insecure_input(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "insecureInput"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "insecureInput"))
 
     @builtins.property
     @jsii.member(jsii_name="javaEndpointInput")
@@ -191,9 +175,7 @@ class OraclepaasProvider(
     @alias.setter
     def alias(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__398bca405f31f1d0c10ecea7b6c8f301838a59ce5b0c16d85c021b1a6ac75b1a)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "alias", value)
 
@@ -205,9 +187,7 @@ class OraclepaasProvider(
     @application_endpoint.setter
     def application_endpoint(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__b087a628719349999822a64fbae4f3dd82d9a7077f01a7f251ca389b7da0a297)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "applicationEndpoint", value)
 
@@ -219,9 +199,7 @@ class OraclepaasProvider(
     @database_endpoint.setter
     def database_endpoint(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__afb7a231ffc48b4e53e45cad5ec408062d91c0dba640347d03e10c26dcba3b15)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "databaseEndpoint", value)
 
@@ -233,9 +211,7 @@ class OraclepaasProvider(
     @identity_domain.setter
     def identity_domain(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__1b8b9ecc4979a0ea4f9a68c05f3d1834bb45d69d4e65668230628a7cdfb3590a)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "identityDomain", value)
 
@@ -243,20 +219,16 @@ class OraclepaasProvider(
     @jsii.member(jsii_name="insecure")
     def insecure(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "insecure"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "insecure"))
 
     @insecure.setter
     def insecure(
         self,
-        value: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]],
+        value: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]],
     ) -> None:
         if __debug__:
-            def stub(
-                value: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]],
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__87d5abc81d7f311cfcde784d951d4ebd4f685db3ccfd6c4427a8740ff5a6d59c)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "insecure", value)
 
@@ -268,9 +240,7 @@ class OraclepaasProvider(
     @java_endpoint.setter
     def java_endpoint(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__def06ad63aef6b5cc5c5496f7d6929b5a3496bea92de55600e6a3379a7337209)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "javaEndpoint", value)
 
@@ -282,9 +252,7 @@ class OraclepaasProvider(
     @max_retries.setter
     def max_retries(self, value: typing.Optional[jsii.Number]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[jsii.Number]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__537bc67479cf9418a38a155a045dea5b43adf79839868defe991ce8d66430fca)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "maxRetries", value)
 
@@ -296,9 +264,7 @@ class OraclepaasProvider(
     @mysql_endpoint.setter
     def mysql_endpoint(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__c90bd1f3f30c8841813e7438d33d1773945e004797d748435077edbe374e6028)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "mysqlEndpoint", value)
 
@@ -310,9 +276,7 @@ class OraclepaasProvider(
     @password.setter
     def password(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__74cdc16bf10a807153af86b32e40a913a210761b3717a7f525a1b25c0dd201a3)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "password", value)
 
@@ -324,9 +288,7 @@ class OraclepaasProvider(
     @user.setter
     def user(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__0bf562fe7de0116ea4c1bfc3c70745f82c35815b18a3f6e9df8a40ccc0a14df1)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "user", value)
 
@@ -357,7 +319,7 @@ class OraclepaasProviderConfig:
         alias: typing.Optional[builtins.str] = None,
         application_endpoint: typing.Optional[builtins.str] = None,
         database_endpoint: typing.Optional[builtins.str] = None,
-        insecure: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        insecure: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         java_endpoint: typing.Optional[builtins.str] = None,
         max_retries: typing.Optional[jsii.Number] = None,
         mysql_endpoint: typing.Optional[builtins.str] = None,
@@ -375,21 +337,7 @@ class OraclepaasProviderConfig:
         :param mysql_endpoint: The HTTP endpoint for Oracle MySQL operations. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/oraclepaas#mysql_endpoint OraclepaasProvider#mysql_endpoint}
         '''
         if __debug__:
-            def stub(
-                *,
-                identity_domain: builtins.str,
-                password: builtins.str,
-                user: builtins.str,
-                alias: typing.Optional[builtins.str] = None,
-                application_endpoint: typing.Optional[builtins.str] = None,
-                database_endpoint: typing.Optional[builtins.str] = None,
-                insecure: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
-                java_endpoint: typing.Optional[builtins.str] = None,
-                max_retries: typing.Optional[jsii.Number] = None,
-                mysql_endpoint: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__a95c82febe1fdc8d74ce8b49bd65d4de04b46a5de7261b61a7ab8727a76712c0)
             check_type(argname="argument identity_domain", value=identity_domain, expected_type=type_hints["identity_domain"])
             check_type(argname="argument password", value=password, expected_type=type_hints["password"])
             check_type(argname="argument user", value=user, expected_type=type_hints["user"])
@@ -400,7 +348,7 @@ class OraclepaasProviderConfig:
             check_type(argname="argument java_endpoint", value=java_endpoint, expected_type=type_hints["java_endpoint"])
             check_type(argname="argument max_retries", value=max_retries, expected_type=type_hints["max_retries"])
             check_type(argname="argument mysql_endpoint", value=mysql_endpoint, expected_type=type_hints["mysql_endpoint"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "identity_domain": identity_domain,
             "password": password,
             "user": user,
@@ -480,13 +428,13 @@ class OraclepaasProviderConfig:
     @builtins.property
     def insecure(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
         '''Skip TLS Verification for self-signed certificates. Should only be used if absolutely required.
 
         Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/oraclepaas#insecure OraclepaasProvider#insecure}
         '''
         result = self._values.get("insecure")
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)
 
     @builtins.property
     def java_endpoint(self) -> typing.Optional[builtins.str]:
@@ -533,3 +481,97 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__cd1e7e516dd8bd0cd036abeaf45b9cabb3becd25c14cfba0ba8459e9673acdc7(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    identity_domain: builtins.str,
+    password: builtins.str,
+    user: builtins.str,
+    alias: typing.Optional[builtins.str] = None,
+    application_endpoint: typing.Optional[builtins.str] = None,
+    database_endpoint: typing.Optional[builtins.str] = None,
+    insecure: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    java_endpoint: typing.Optional[builtins.str] = None,
+    max_retries: typing.Optional[jsii.Number] = None,
+    mysql_endpoint: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__398bca405f31f1d0c10ecea7b6c8f301838a59ce5b0c16d85c021b1a6ac75b1a(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b087a628719349999822a64fbae4f3dd82d9a7077f01a7f251ca389b7da0a297(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__afb7a231ffc48b4e53e45cad5ec408062d91c0dba640347d03e10c26dcba3b15(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1b8b9ecc4979a0ea4f9a68c05f3d1834bb45d69d4e65668230628a7cdfb3590a(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__87d5abc81d7f311cfcde784d951d4ebd4f685db3ccfd6c4427a8740ff5a6d59c(
+    value: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__def06ad63aef6b5cc5c5496f7d6929b5a3496bea92de55600e6a3379a7337209(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__537bc67479cf9418a38a155a045dea5b43adf79839868defe991ce8d66430fca(
+    value: typing.Optional[jsii.Number],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c90bd1f3f30c8841813e7438d33d1773945e004797d748435077edbe374e6028(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__74cdc16bf10a807153af86b32e40a913a210761b3717a7f525a1b25c0dd201a3(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0bf562fe7de0116ea4c1bfc3c70745f82c35815b18a3f6e9df8a40ccc0a14df1(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a95c82febe1fdc8d74ce8b49bd65d4de04b46a5de7261b61a7ab8727a76712c0(
+    *,
+    identity_domain: builtins.str,
+    password: builtins.str,
+    user: builtins.str,
+    alias: typing.Optional[builtins.str] = None,
+    application_endpoint: typing.Optional[builtins.str] = None,
+    database_endpoint: typing.Optional[builtins.str] = None,
+    insecure: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    java_endpoint: typing.Optional[builtins.str] = None,
+    max_retries: typing.Optional[jsii.Number] = None,
+    mysql_endpoint: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
